==> doxygen-1.9.6-1-src.tar.xz: doxygen-1.9.6/doc_internal/commands_history.md <==
\page pg_cmds Overview of introduction of special commands

The following table gives an overview of the doxygen special commands and the version in which they were introduced.

<dl class="multicol">
<dt>New in 1.0.0</dt> <dd>\\\\</dd>
<dt></dt>             <dd>\\#</dd>
<dt></dt>             <dd>\\$</dd>
<dt></dt>             <dd>\\&</dd>
<dt></dt>             <dd>\\@@</dd>
<dt></dt>             <dd>\\<</dd>
<dt></dt>             <dd>\\></dd>
<dt></dt>             <dd>\\a</dd>
<dt></dt>             <dd>\\addindex</dd>
<dt></dt>             <dd>\\anchor</dd>
<dt></dt>             <dd>\\arg</dd>
<dt></dt>             <dd>\\author</dd>
<dt></dt>             <dd>\\b</dd>
<dt></dt>             <dd>\\brief</dd>
<dt></dt>             <dd>\\bug</dd>
<dt></dt>             <dd>\\c</dd>
<dt></dt>             <dd>\\class</dd>
<dt></dt>             <dd>\\code</dd>
<dt></dt>             <dd>\\date</dd>
<dt></dt>             <dd>\\def</dd>
<dt></dt>             <dd>\\defgroup</dd>
<dt></dt>             <dd>\\deprecated</dd>
<dt></dt>             <dd>\\dontinclude</dd>
<dt></dt>             <dd>\\e</dd>
<dt></dt>             <dd>\\endcode</dd>
<dt></dt>             <dd>\\endhtmlonly</dd>
<dt></dt>             <dd>\\endlatexonly</dd>
<dt></dt>             <dd>\\endlink</dd>
<dt></dt>             <dd>endverbatim</dd>
<dt></dt>             <dd>\\enum</dd>
<dt></dt>             <dd>\\example</dd>
<dt></dt>             <dd>\\exception</dd>
<dt></dt>             <dd>\\f$</dd>
<dt></dt>             <dd>\\f[</dd>
<dt></dt>             <dd>\\f]</dd>
<dt></dt>             <dd>\\file</dd>
<dt></dt>             <dd>\\fn</dd>
<dt></dt>             <dd>\\htmlonly</dd>
<dt></dt>             <dd>\\image</dd>
<dt></dt>             <dd>\\include</dd>
<dt></dt>             <dd>\\ingroup</dd>
<dt></dt>             <dd>\\internal</dd>
<dt></dt>             <dd>\\latexonly</dd>
<dt></dt>             <dd>\\line</dd>
<dt></dt>             <dd>\\link</dd>
<dt></dt>             <dd>\\mainpage</dd>
<dt></dt>             <dd>\\namespace</dd>
<dt></dt>             <dd>\\overload</dd>
<dt></dt>             <dd>\\page</dd>
<dt></dt>             <dd>\\par</dd>
<dt></dt>             <dd>\\param</dd>
<dt></dt>             <dd>\\ref</dd>
<dt></dt>             <dd>\\relates</dd>
<dt></dt>             <dd>\\return</dd>
<dt></dt>             <dd>\\retval</dd>
<dt></dt>             <dd>\\sa</dd>
<dt></dt>             <dd>\\section</dd>
<dt></dt>             <dd>\\skip</dd>
<dt></dt>             <dd>\\skipline</dd>
<dt></dt>             <dd>\\struct</dd>
<dt></dt>             <dd>\\subsection</dd>
<dt></dt>             <dd>\\throw</dd>
<dt></dt>             <dd>\\typedef</dd>
<dt></dt>             <dd>\\union</dd>
<dt></dt>             <dd>\\until</dd>
<dt></dt>             <dd>\\var</dd>
<dt></dt>             <dd>\\verbatim</dd>
<dt></dt>             <dd>\\verbinclude</dd>
<dt></dt>             <dd>\\version</dd>
<dt></dt>             <dd>\\warning</dd>
<dt>New in 1.1.0</dt><dd>\\invariant</dd>
<dt></dt>             <dd>\\post</dd>
<dt></dt>             <dd>\\pre</dd>
<dt>New in 1.1.3</dt><dd>\\endif</dd>
<dt></dt>             <dd>\\if</dd>
<dt></dt>             <dd>\\name</dd>
<dt>New in 1.1.4</dt><dd>\\hideinitializer</dd>
<dt></dt>             <dd>\\nosubgrouping</dd>
<dt></dt>             <dd>\\showinitializer</dd>
<dt></dt>             <dd>\\todo</dd>
<dt>New in 1.1.5</dt><dd>\\attention</dd>
<dt></dt>             <dd>\\remarks</dd>
<dt></dt>             <dd>\\since</dd>
<dt>New in 1.2.0</dt><dd>\\em</dd>
<dt></dt>             <dd>\\li</dd>
<dt></dt>             <dd>\\note</dd>
<dt></dt>             <dd>\\p</dd>
<dt>New in 1.2.1</dt><dd>\\test</dd>
<dt>New in 1.2.7</dt><dd>\\addtogroup</dd>
<dt></dt>             <dd>\\htmlinclude</dd>
<dt>New in 1.2.8</dt><dd>\\interface</dd>
<dt></dt>             <dd>\\weakgroup</dd>
<dt>New in 1.2.9.1</dt><dd>\\else</dd>
<dt></dt>             <dd>\\elseif</dd>
<dt></dt>             <dd>\\ifnot</dd>
<dt>New in 1.2.10</dt><dd>\\dotfile</dd>
<dt></dt>             <dd>\\package</dd>
<dt>New in 1.2.14</dt><dd>\\~</dd>
<dt>New in 1.2.17</dt><dd>\\copydoc</dd>
<dt>New in 1.2.18</dt><dd>\\n</dd>
<dt></dt>             <dd>\\subsubsection</dd>
<dt>New in 1.3.1</dt><dd>\\xrefitem</dd>
<dt>New in 1.3.2</dt><dd>\\callgraph</dd>
<dt></dt>             <dd>\\endxmlonly</dd>
<dt></dt>             <dd>\\xmlonly</dd>
<dt>New in 1.3.4</dt><dd>\\dot</dd>
<dt></dt>             <dd>\\enddot</dd>
<dt></dt>             <dd>\\relatesalso</dd>
<dt>New in 1.3.7</dt><dd>\\%</dd>
<dt></dt>             <dd>\\endmanonly</dd>
<dt></dt>             <dd>\\includelineno</dd>
<dt></dt>             <dd>\\manonly</dd>
<dt></dt>             <dd>\\property</dd>
<dt>New in 1.3.8</dt><dd>\\category</dd>
<dt></dt>             <dd>\\paragraph</dd>
<dt></dt>             <dd>\\private</dd>
<dt></dt>             <dd>\\privatesection</dd>
<dt></dt>             <dd>\\protected</dd>
<dt></dt>             <dd>\\protectedsection</dd>
<dt></dt>             <dd>\\protocol</dd>
<dt></dt>             <dd>\\public</dd>
<dt></dt>             <dd>\\publicsection</dd>
<dt>New in 1.3.9</dt><dd>\\dir</dd>
<dt>New in 1.4.0</dt><dd>\\cond</dd>
<dt></dt>             <dd>\\endcond</dd>
<dt></dt>             <dd>\\see</dd>
<dt>New in 1.4.2</dt><dd>\\subpage</dd>
<dt>New in 1.4.7</dt><dd>\\callergraph</dd>
<dt>New in 1.5.2</dt><dd>\\endmsc</dd>
<dt></dt>             <dd>\\msc</dd>
<dt>New in 1.5.3</dt><dd>\\details</dd>
<dt>New in 1.5.4</dt><dd>\\f{</dd>
<dt></dt>             <dd>\\f}</dd>
<dt>New in 1.5.5</dt><dd>\\headerfile</dd>
<dt>New in 1.5.6</dt><dd>\\copybrief</dd>
<dt></dt>             <dd>\\copydetails</dd>
<dt></dt>             <dd>\\tparam</dd>
<dt>New in 1.5.7</dt><dd>\\extends</dd>
<dt></dt>             <dd>\\implements</dd>
<dt></dt>             <dd>\\memberof</dd>
<dt>New in 1.6.2</dt><dd>\\"</dd>
<dt>New in 1.7.2</dt><dd>\\authors</dd>
<dt></dt>             <dd>\\endinternal</dd>
<dt></dt>             <dd>\\endrtfonly</dd>
<dt></dt>             <dd>\\mscfile</dd>
<dt></dt>             <dd>\\related</dd>
<dt></dt>             <dd>\\relatedalso</dd>
<dt></dt>             <dd>\\remark</dd>
<dt></dt>             <dd>\\returns</dd>
<dt></dt>             <dd>\\rtfonly</dd>
<dt></dt>             <dd>\\short</dd>
<dt></dt>             <dd>\\throws</dd>
<dt>New in 1.7.3</dt><dd>\\::</dd>
<dt></dt>             <dd>\\result</dd>
<dt>New in 1.7.5</dt><dd>\\cite</dd>
<dt></dt>             <dd>\\copyright</dd>
<dt></dt>             <dd>\\snippet</dd>
<dt>New in 1.8.0</dt><dd>\\.</dd>
<dt></dt>             <dd>\\tableofcontents</dd>
<dt>New in 1.8.3</dt><dd>\\vhdlflow</dd>
<dt>New in 1.8.4</dt><dd>\\|</dd>
<dt></dt>             <dd>\\docbookonly</dd>
<dt></dt>             <dd>\\enddocbookonly</dd>
<dt></dt>             <dd>\\endsecreflist</dd>
<dt></dt>             <dd>\\idlexcept</dd>
<dt></dt>             <dd>\\pure</dd>
<dt></dt>             <dd>\\refitem</dd>
<dt></dt>             <dd>\\secreflist</dd>
<dt>New in 1.8.6</dt><dd>\\diafile</dd>
<dt></dt>             <dd>\\endparblock</dd>
<dt></dt>             <dd>\\parblock</dd>
<dt>New in 1.8.7</dt><dd>\\\\--</dd>
<dt></dt>             <dd>\\\\---</dd>
<dt></dt>             <dd>\\latexinclude</dd>
<dt>New in 1.8.8</dt><dd>\\enduml</dd>
<dt></dt>             <dd>\\startuml</dd>
<dt>New in 1.8.10</dt><dd>\\hidecallergraph</dd>
<dt></dt>             <dd>\\hidecallgraph</dd>
<dt>New in 1.8.12</dt><dd>\\includedoc</dd>
<dt></dt>             <dd>\\snippetdoc</dd>
<dt></dt>             <dd>\\snippetlineno</dd>
<dt>New in 1.8.15</dt><dd>\\=</dd>
<dt></dt>             <dd>\\emoji</dd>
<dt></dt>             <dd>\\hiderefby</dd>
<dt></dt>             <dd>\\hiderefs</dd>
<dt></dt>             <dd>\\showrefby</dd>
<dt></dt>             <dd>\\showrefs</dd>
<dt>New in 1.8.18</dt><dd>\\docbookinclude</dd>
<dt></dt>             <dd>\\maninclude</dd>
<dt></dt>             <dd>\\rtfinclude</dd>
<dt></dt>             <dd>\\xmlinclude</dd>
<dt>New in 1.9.0</dt><dd>\\noop</dd>
<dt></dt>             <dd>\\static</dd>
<dt>New in 1.9.2</dt><dd>\\concept</dd>
<dt></dt>             <dd>\\f(</dd>
<dt></dt>             <dd>\\f)</dd>
<dt>New in 1.9.3</dt><dd>\\raisewarning</dd>
<dt>New in 1.9.5</dt><dd>\\fileinfo</dd>
<dt></dt>             <dd>\\lineinfo</dd>
<dt></dt>             <dd>\\showdate</dd>
<dt>New in 1.9.6</dt><dd>\\qualifier</dd>
</dl>

==> doxygen-1.12.0-1-src.tar.xz: doxygen-1.12.0/doc_internal/commands_history.md <==
\page pg_cmds Overview of introduction of special commands

The following table gives an overview of the doxygen special commands and the version in which they were introduced.

<dl class="multicol">
<dt>New in 1.0.0</dt> <dd>\\\\</dd>
<dt></dt>             <dd>\\#</dd>
<dt></dt>             <dd>\\$</dd>
<dt></dt>             <dd>\\&</dd>
<dt></dt>             <dd>\\@@</dd>
<dt></dt>             <dd>\\<</dd>
<dt></dt>             <dd>\\></dd>
<dt></dt>             <dd>\\a</dd>
<dt></dt>             <dd>\\addindex</dd>
<dt></dt>             <dd>\\anchor</dd>
<dt></dt>             <dd>\\arg</dd>
<dt></dt>             <dd>\\author</dd>
<dt></dt>             <dd>\\b</dd>
<dt></dt>             <dd>\\brief</dd>
<dt></dt>             <dd>\\bug</dd>
<dt></dt>             <dd>\\c</dd>
<dt></dt>             <dd>\\class</dd>
<dt></dt>             <dd>\\code</dd>
<dt></dt>             <dd>\\date</dd>
<dt></dt>             <dd>\\def</dd>
<dt></dt>             <dd>\\defgroup</dd>
<dt></dt>             <dd>\\deprecated</dd>
<dt></dt>             <dd>\\dontinclude</dd>
<dt></dt>             <dd>\\e</dd>
<dt></dt>             <dd>\\endcode</dd>
<dt></dt>             <dd>\\endhtmlonly</dd>
<dt></dt>             <dd>\\endlatexonly</dd>
<dt></dt>             <dd>\\endlink</dd>
<dt></dt>             <dd>\\endverbatim</dd>
<dt></dt>             <dd>\\enum</dd>
<dt></dt>             <dd>\\example</dd>
<dt></dt>             <dd>\\exception</dd>
<dt></dt>             <dd>\\f$</dd>
<dt></dt>             <dd>\\f[</dd>
<dt></dt>             <dd>\\f]</dd>
<dt></dt>             <dd>\\file</dd>
<dt></dt>             <dd>\\fn</dd>
<dt></dt>             <dd>\\htmlonly</dd>
<dt></dt>             <dd>\\image</dd>
<dt></dt>             <dd>\\include</dd>
<dt></dt>             <dd>\\ingroup</dd>
<dt></dt>             <dd>\\internal</dd>
<dt></dt>             <dd>\\latexonly</dd>
<dt></dt>             <dd>\\line</dd>
<dt></dt>             <dd>\\link</dd>
<dt></dt>             <dd>\\mainpage</dd>
<dt></dt>             <dd>\\namespace</dd>
<dt></dt>             <dd>\\overload</dd>
<dt></dt>             <dd>\\page</dd>
<dt></dt>             <dd>\\par</dd>
<dt></dt>             <dd>\\param</dd>
<dt></dt>             <dd>\\ref</dd>
<dt></dt>             <dd>\\relates</dd>
<dt></dt>             <dd>\\return</dd>
<dt></dt>             <dd>\\retval</dd>
<dt></dt>             <dd>\\sa</dd>
<dt></dt>             <dd>\\section</dd>
<dt></dt>             <dd>\\skip</dd>
<dt></dt>             <dd>\\skipline</dd>
<dt></dt>             <dd>\\struct</dd>
<dt></dt>             <dd>\\subsection</dd>
<dt></dt>             <dd>\\throw</dd>
<dt></dt>             <dd>\\typedef</dd>
<dt></dt>             <dd>\\union</dd>
<dt></dt>             <dd>\\until</dd>
<dt></dt>             <dd>\\var</dd>
<dt></dt>             <dd>\\verbatim</dd>
<dt></dt>             <dd>\\verbinclude</dd>
<dt></dt>             <dd>\\version</dd>
<dt></dt>             <dd>\\warning</dd>
<dt>New in 1.1.0</dt><dd>\\invariant</dd>
<dt></dt>             <dd>\\post</dd>
<dt></dt>             <dd>\\pre</dd>
<dt>New in 1.1.3</dt><dd>\\endif</dd>
<dt></dt>             <dd>\\if</dd>
<dt></dt>             <dd>\\name</dd>
<dt>New in 1.1.4</dt><dd>\\hideinitializer</dd>
<dt></dt>             <dd>\\nosubgrouping</dd>
<dt></dt>             <dd>\\showinitializer</dd>
<dt></dt>             <dd>\\todo</dd>
<dt>New in 1.1.5</dt><dd>\\attention</dd>
<dt></dt>             <dd>\\remarks</dd>
<dt></dt>             <dd>\\since</dd>
<dt>New in 1.2.0</dt><dd>\\em</dd>
<dt></dt>             <dd>\\li</dd>
<dt></dt>             <dd>\\note</dd>
<dt></dt>             <dd>\\p</dd>
<dt>New in 1.2.1</dt><dd>\\test</dd>
<dt>New in 1.2.7</dt><dd>\\addtogroup</dd>
<dt></dt>             <dd>\\htmlinclude</dd>
<dt>New in 1.2.8</dt><dd>\\interface</dd>
<dt></dt>             <dd>\\weakgroup</dd>
<dt>New in 1.2.9.1</dt><dd>\\else</dd>
<dt></dt>             <dd>\\elseif</dd>
<dt></dt>             <dd>\\ifnot</dd>
<dt>New in 1.2.10</dt><dd>\\dotfile</dd>
<dt></dt>             <dd>\\package</dd>
<dt>New in 1.2.14</dt><dd>\\~</dd>
<dt>New in 1.2.17</dt><dd>\\copydoc</dd>
<dt>New in 1.2.18</dt><dd>\\n</dd>
<dt></dt>             <dd>\\subsubsection</dd>
<dt>New in 1.3.1</dt><dd>\\xrefitem</dd>
<dt>New in 1.3.2</dt><dd>\\callgraph</dd>
<dt></dt>             <dd>\\endxmlonly</dd>
<dt></dt>             <dd>\\xmlonly</dd>
<dt>New in 1.3.4</dt><dd>\\dot</dd>
<dt></dt>             <dd>\\enddot</dd>
<dt></dt>             <dd>\\relatesalso</dd>
<dt>New in 1.3.7</dt><dd>\\%</dd>
<dt></dt>             <dd>\\endmanonly</dd>
<dt></dt>             <dd>\\includelineno</dd>
<dt></dt>             <dd>\\manonly</dd>
<dt></dt>             <dd>\\property</dd>
<dt>New in 1.3.8</dt><dd>\\category</dd>
<dt></dt>             <dd>\\paragraph</dd>
<dt></dt>             <dd>\\private</dd>
<dt></dt>             <dd>\\privatesection</dd>
<dt></dt>             <dd>\\protected</dd>
<dt></dt>             <dd>\\protectedsection</dd>
<dt></dt>             <dd>\\protocol</dd>
<dt></dt>             <dd>\\public</dd>
<dt></dt>             <dd>\\publicsection</dd>
<dt>New in 1.3.9</dt><dd>\\dir</dd>
<dt>New in 1.4.0</dt><dd>\\cond</dd>
<dt></dt>             <dd>\\endcond</dd>
<dt></dt>             <dd>\\see</dd>
<dt>New in 1.4.2</dt><dd>\\subpage</dd>
<dt>New in 1.4.7</dt><dd>\\callergraph</dd>
<dt>New in 1.5.2</dt><dd>\\endmsc</dd>
<dt></dt>             <dd>\\msc</dd>
<dt>New in 1.5.3</dt><dd>\\details</dd>
<dt>New in 1.5.4</dt><dd>\\f{</dd>
<dt></dt>             <dd>\\f}</dd>
<dt>New in 1.5.5</dt><dd>\\headerfile</dd>
<dt>New in 1.5.6</dt><dd>\\copybrief</dd>
<dt></dt>             <dd>\\copydetails</dd>
<dt></dt>             <dd>\\tparam</dd>
<dt>New in 1.5.7</dt><dd>\\extends</dd>
<dt></dt>             <dd>\\implements</dd>
<dt></dt>             <dd>\\memberof</dd>
<dt>New in 1.6.2</dt><dd>\\"</dd>
<dt>New in 1.7.2</dt><dd>\\authors</dd>
<dt></dt>             <dd>\\endinternal</dd>
<dt></dt>             <dd>\\endrtfonly</dd>
<dt></dt>             <dd>\\mscfile</dd>
<dt></dt>             <dd>\\related</dd>
<dt></dt>             <dd>\\relatedalso</dd>
<dt></dt>             <dd>\\remark</dd>
<dt></dt>             <dd>\\returns</dd>
<dt></dt>             <dd>\\rtfonly</dd>
<dt></dt>             <dd>\\short</dd>
<dt></dt>             <dd>\\throws</dd>
<dt>New in 1.7.3</dt><dd>\\::</dd>
<dt></dt>             <dd>\\result</dd>
<dt>New in 1.7.5</dt><dd>\\cite</dd>
<dt></dt>             <dd>\\copyright</dd>
<dt></dt>             <dd>\\snippet</dd>
<dt>New in 1.8.0</dt><dd>\\.</dd>
<dt></dt>             <dd>\\tableofcontents</dd>
<dt>New in 1.8.3</dt><dd>\\vhdlflow</dd>
<dt>New in 1.8.4</dt><dd>\\|</dd>
<dt></dt>             <dd>\\docbookonly</dd>
<dt></dt>             <dd>\\enddocbookonly</dd>
<dt></dt>             <dd>\\endsecreflist</dd>
<dt></dt>             <dd>\\idlexcept</dd>
<dt></dt>             <dd>\\pure</dd>
<dt></dt>             <dd>\\refitem</dd>
<dt></dt>             <dd>\\secreflist</dd>
<dt>New in 1.8.6</dt><dd>\\diafile</dd>
<dt></dt>             <dd>\\endparblock</dd>
<dt></dt>             <dd>\\parblock</dd>
<dt>New in 1.8.7</dt><dd>\\\--</dd>
<dt></dt>             <dd>\\\---</dd>
<dt></dt>             <dd>\\latexinclude</dd>
<dt>New in 1.8.8</dt><dd>\\enduml</dd>
<dt></dt>             <dd>\\startuml</dd>
<dt>New in 1.8.10</dt><dd>\\hidecallergraph</dd>
<dt></dt>             <dd>\\hidecallgraph</dd>
<dt>New in 1.8.12</dt><dd>\\includedoc</dd>
<dt></dt>             <dd>\\snippetdoc</dd>
<dt></dt>             <dd>\\snippetlineno</dd>
<dt>New in 1.8.15</dt><dd>\\=</dd>
<dt></dt>             <dd>\\emoji</dd>
<dt></dt>             <dd>\\hiderefby</dd>
<dt></dt>             <dd>\\hiderefs</dd>
<dt></dt>             <dd>\\showrefby</dd>
<dt></dt>             <dd>\\showrefs</dd>
<dt>New in 1.8.18</dt><dd>\\docbookinclude</dd>
<dt></dt>             <dd>\\maninclude</dd>
<dt></dt>             <dd>\\rtfinclude</dd>
<dt></dt>             <dd>\\xmlinclude</dd>
<!-- PLACEHOLDER -->
</dl>
